"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
exports.createLocalResolvers = exports.createSchema = void 0;
var defaults_1 = __importDefault(require("../defaults"));
var resolver_builder_1 = __importDefault(require("./resolver-builder"));
var schema_builder_1 = __importDefault(require("./schema-builder"));
/**
 * Creates a GraphQL schema from the given set of content types.
 * @param options (Optional) Where to locate the contentful content types to
 *   generate the GraphQL schema (default: './contentful-schema.json')
 * @returns
 */
function createSchema(options) {
    return new schema_builder_1["default"](options).build();
}
exports.createSchema = createSchema;
/**
 * Creates a set of Apollo local resolvers around a Data Source.  The resolvers
 * include a set of Query resolvers matching the content types in the
 * contentful-schema.json file.
 * @param dataSource A queryable data source providing methods to retrieve entries
 * and assets.
 * @param options (Optional) Where to locate the contentful content types to generate
 *   the resolvers (default: './contentful-schema.json')
 * @returns
 * @example
 *  const dataSource = withSync(new InMemoryDataSource())
 *  createLocalResolvers(dataSource)
 */
function createLocalResolvers(dataSource, options) {
    return new resolver_builder_1["default"](dataSource, __assign(__assign({}, defaults_1["default"]), options)).build();
}
exports.createLocalResolvers = createLocalResolvers;
//# sourceMappingURL=index.js.map