"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var types_1 = require("../types");
var content_type_resolver_builder_1 = __importDefault(require("./content-type-resolver-builder"));
var query_resolver_builder_1 = __importDefault(require("./query-resolver-builder"));
var ResolverBuilder = /** @class */ (function () {
    function ResolverBuilder(dataSource, options) {
        this.dataSource = dataSource;
        var opts = Object.assign({
            filename: './contentful-schema.json',
            logger: console
        }, options);
        this.options = opts;
    }
    ResolverBuilder.prototype.build = function () {
        var _this = this;
        var contentfulSchema;
        if ('contentTypes' in this.options) {
            contentfulSchema = { contentTypes: this.options.contentTypes };
        }
        else {
            contentfulSchema = require(this.options.filename);
        }
        var _a = this.options, namespace = _a.namespace, queryNamespace = _a.queryNamespace;
        var resolvers = __assign({}, contentfulSchema.contentTypes.reduce(function (types, ct) {
            return __assign(__assign({}, types), new content_type_resolver_builder_1["default"](_this.dataSource, _this.options, ct).build());
        }, {}));
        var Query = __assign(__assign(__assign({}, new query_resolver_builder_1["default"](this.dataSource, this.options, 'Entry').build().Query), new query_resolver_builder_1["default"](this.dataSource, this.options, 'Asset').build().Query), contentfulSchema.contentTypes.reduce(function (resolvers, ct) {
            return __assign(__assign({}, resolvers), new query_resolver_builder_1["default"](_this.dataSource, _this.options, ct.sys.id).build().Query);
        }, {}));
        if (queryNamespace) {
            // we put the Query inside a namespaced type that we reference in the top level
            var QueryTypeName_1 = (0, types_1.namespacedTypeName)('Query', queryNamespace);
            resolvers[QueryTypeName_1] = Query;
            resolvers['Query'] = {};
            resolvers['Query'][queryNamespace] = function () {
                return {
                    __typename: QueryTypeName_1,
                    _id: QueryTypeName_1
                };
            };
        }
        else {
            // we directly add our resolvers to the query
            resolvers['Query'] = Query;
        }
        resolvers[(0, types_1.namespacedTypeName)('Asset', namespace)] = (0, types_1.assetFieldResolver)(namespace);
        return resolvers;
    };
    return ResolverBuilder;
}());
exports["default"] = ResolverBuilder;
//# sourceMappingURL=index.js.map