"use strict";
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var inflection_1 = __importDefault(require("inflection"));
var graphql_type_json_1 = __importDefault(require("graphql-type-json"));
var graphql_1 = require("graphql");
var types_1 = require("../types");
var util_1 = require("../../util");
var ContentTypeWriter = /** @class */ (function () {
    function ContentTypeWriter(contentType, contentTypeMap, collectionTypeMap, namespace) {
        var _this = this;
        this.contentType = contentType;
        this.contentTypeMap = contentTypeMap;
        this.collectionTypeMap = collectionTypeMap;
        this.namespace = namespace;
        this.write = function () {
            var contentType = _this.contentType;
            var type = new graphql_1.GraphQLObjectType({
                name: _this.className,
                interfaces: [_this.namespace.Entry],
                fields: function () {
                    var fields = {};
                    contentType.fields.forEach(function (f) {
                        return _this.writeField(f, fields);
                    });
                    return fields;
                }
            });
            _this.contentTypeMap.set(_this.className, type);
            var collection = new graphql_1.GraphQLObjectType({
                name: "".concat(_this.className, "Collection"),
                fields: {
                    skip: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLInt) },
                    limit: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLInt) },
                    total: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLInt) },
                    items: { type: new graphql_1.GraphQLNonNull(new graphql_1.GraphQLList(type)) }
                }
            });
            _this.collectionTypeMap.set(_this.className, collection);
            return {
                type: type,
                collection: collection
            };
        };
        this.linkedTypes = [];
        var name = (0, util_1.idToName)(contentType.sys.id);
        this.className = this.namespace.toType(name);
    }
    ContentTypeWriter.prototype.writeField = function (field, fields) {
        var nullable = field.omitted || (!field.required);
        var type = this.writeFieldType(field);
        fields[field.id] = {
            type: nullable ? type : new graphql_1.GraphQLNonNull(type)
        };
    };
    ContentTypeWriter.prototype.writeFieldType = function (field) {
        if (field.omitted) {
            return types_1.GraphQLNever;
        }
        switch (field.type) {
            case 'Symbol':
            case 'Text':
            case 'Date':
                return this.writePotentialUnionType(field) || graphql_1.GraphQLString;
            case 'Integer':
                return this.writePotentialUnionType(field) || graphql_1.GraphQLInt;
            case 'Number':
                return this.writePotentialUnionType(field) || graphql_1.GraphQLFloat;
            case 'Boolean':
                return graphql_1.GraphQLBoolean;
            case 'Location':
                return this.namespace.GraphQLLocation;
            case 'Link':
                if (field.linkType == 'Asset') {
                    return this.namespace.Asset;
                }
                else {
                    return this.resolveLinkContentType(field);
                }
            case 'Array':
                {
                    var itemType = this.writeFieldType(Object.assign({ id: field.id }, field.items));
                    if (field.items && field.items.type == 'Link') {
                        if (itemType == this.namespace.Asset) {
                            return this.namespace.AssetCollection;
                        }
                        else if (itemType == this.namespace.Entry) {
                            return this.namespace.EntryCollection;
                        }
                        return this.writeLinkCollectionType(itemType);
                    }
                    else {
                        return new graphql_1.GraphQLList(itemType);
                    }
                }
            default:
                return graphql_type_json_1["default"];
        }
    };
    ContentTypeWriter.prototype.resolveLinkContentType = function (field) {
        var _a;
        var _this = this;
        var validation = field.validations &&
            field.validations.filter(util_1.isLinkContentTypeValidation).find(function (v) {
                return v.linkContentType.length > 0;
            });
        if (!validation) {
            return this.namespace.Entry;
        }
        (_a = this.linkedTypes).push.apply(_a, __spreadArray([], __read(validation.linkContentType), false));
        if (validation.linkContentType.length == 1) {
            var name_1 = this.namespace.toType((0, util_1.idToName)(validation.linkContentType[0]));
            var resolved = this.contentTypeMap.get(name_1);
            if (!resolved) {
                throw new Error("Could not resolve content type '".concat(name_1, "'"));
            }
            return resolved;
        }
        var unionName = this.namespace.toType((0, util_1.unionTypeDefName)(this.contentType.sys.id, field));
        return new graphql_1.GraphQLUnionType({
            name: unionName,
            types: function () { return validation.linkContentType.map(function (val) {
                var name = _this.namespace.toType((0, util_1.idToName)(val));
                var resolved = _this.contentTypeMap.get(name);
                if (!resolved) {
                    throw new Error("Could not resolve content type '".concat(name, "'"));
                }
                return resolved;
            }); }
        });
    };
    ContentTypeWriter.prototype.writeLinkCollectionType = function (itemType) {
        var name = this.namespace.toType(itemType.name);
        var collection = this.collectionTypeMap.get(name);
        if (!collection) {
            collection = new graphql_1.GraphQLObjectType({
                name: "".concat(name, "Collection"),
                fields: {
                    skip: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLInt) },
                    limit: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLInt) },
                    total: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLInt) },
                    items: { type: new graphql_1.GraphQLNonNull(new graphql_1.GraphQLList(itemType)) }
                }
            });
            this.collectionTypeMap.set(name, collection);
        }
        return collection;
    };
    ContentTypeWriter.prototype.writePotentialUnionType = function (field) {
        if (!field.validations) {
            return null;
        }
        var validation = field.validations.find(function (v) { return v["in"] && v["in"].length > 0; });
        if (validation) {
            var name_2 = this.namespace.toType((0, util_1.unionTypeDefName)(this.contentType.sys.id, field));
            return new graphql_1.GraphQLEnumType({
                name: name_2,
                values: validation["in"].reduce(function (map, val) {
                    map[inflection_1["default"].underscore((0, util_1.idToName)(val.toString()))] = {
                        value: val
                    };
                    return map;
                }, {})
            });
        }
    };
    return ContentTypeWriter;
}());
exports["default"] = ContentTypeWriter;
//# sourceMappingURL=content-type-writer.js.map