"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var graphql_1 = require("graphql");
var inflection_1 = __importDefault(require("inflection"));
var content_type_writer_1 = __importDefault(require("./content-type-writer"));
var util_1 = require("../../util");
var types_1 = require("../types");
var SchemaBuilder = /** @class */ (function () {
    function SchemaBuilder(options) {
        this.options = options;
        this.namespace = (0, types_1.namespace)(options.namespace);
    }
    SchemaBuilder.prototype.build = function () {
        var _a;
        var _this = this;
        var contentfulSchema = { contentTypes: this.options.contentTypes };
        var contentTypeMap = new Map();
        var helperTypeMap = new Map();
        var graphQLTypes = contentfulSchema.contentTypes.map(function (ct) { return (__assign({ contentType: ct.sys.id }, new content_type_writer_1["default"](ct, contentTypeMap, helperTypeMap, _this.namespace).write())); });
        var baseFields = {
            asset: {
                type: this.namespace.Asset,
                args: {
                    id: { type: graphql_1.GraphQLString }
                }
            },
            assetCollection: {
                type: this.namespace.AssetCollection,
                args: {
                    skip: { type: graphql_1.GraphQLString },
                    limit: { type: graphql_1.GraphQLString }
                }
            },
            entry: {
                type: this.namespace.Entry,
                args: {
                    id: { type: graphql_1.GraphQLString }
                }
            },
            entryCollection: {
                type: this.namespace.EntryCollection,
                args: {
                    skip: { type: graphql_1.GraphQLString },
                    limit: { type: graphql_1.GraphQLString }
                }
            }
        };
        var queryNamespace = this.options.queryNamespace;
        var QueryTypeName = (0, types_1.namespacedTypeName)('Query', queryNamespace);
        var QueryType = new graphql_1.GraphQLObjectType({
            name: QueryTypeName,
            fields: graphQLTypes.reduce(function (fields, _a) {
                var contentType = _a.contentType, type = _a.type, collection = _a.collection;
                var queryFieldName = inflection_1["default"].camelize((0, util_1.idToName)(contentType), true);
                fields[queryFieldName] = {
                    type: type,
                    args: {
                        id: { type: graphql_1.GraphQLString }
                    }
                };
                fields["".concat(queryFieldName, "Collection")] = {
                    type: collection,
                    args: {
                        skip: { type: graphql_1.GraphQLString },
                        limit: { type: graphql_1.GraphQLString }
                    }
                };
                return fields;
            }, baseFields)
        });
        if (!queryNamespace) {
            // No namespace - the Query is at the root of the schema
            return new graphql_1.GraphQLSchema({
                query: QueryType
            });
        }
        // A Query object with a single field that wraps up our actual Query object
        var Query = new graphql_1.GraphQLObjectType({
            name: 'Query',
            fields: (_a = {},
                _a[queryNamespace] = {
                    type: QueryType
                },
                _a)
        });
        return new graphql_1.GraphQLSchema({
            query: Query
        });
    };
    return SchemaBuilder;
}());
exports["default"] = SchemaBuilder;
//# sourceMappingURL=index.js.map