"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
exports.useDataSource = exports.LocalSchemaProvider = void 0;
var react_1 = __importDefault(require("react"));
var debounce_1 = __importDefault(require("lodash/debounce"));
var syncEngine_1 = require("../syncEngine");
var backup_1 = require("../backup");
var resolve_1 = require("../resolve");
var context = react_1["default"].createContext({
    dataSource: 'Please use the LocalSchemaProvider'
});
/**
 * Provides a data source to power the query hooks
 */
function LocalSchemaProvider(_a) {
    var children = _a.children, dataSource = _a.dataSource, Loading = _a.Loading;
    // Ensure the query hooks can "resolve" entries
    (0, resolve_1.addResolve)(dataSource);
    var _b = __read(react_1["default"].useState(1), 2), revision = _b[0], setRevision = _b[1];
    /**
     * A function to trigger a resync on-demand
     */
    var resync = react_1["default"].useMemo(function () {
        if (!(0, syncEngine_1.hasSync)(dataSource)) {
            return function () { throw new Error('Sync is not supported.  Did you wrap your data source with `withSync`?'); };
        }
        if (!(0, backup_1.hasBackup)(dataSource)) {
            console.warn('No backup method found.  Did you wrap your data source with `withBackup`?');
            // No backup so all we can do is sync
            return (0, debounce_1["default"])(dataSource.sync.bind(dataSource), 400, { leading: true });
        }
        return (0, debounce_1["default"])(function () {
            var syncPromise = dataSource.sync();
            // In the background, after the sync finishes, backup to AsyncStorage.
            // If this fails, we don't really care because at least the sync succeeded.
            syncPromise.then(function () { return dataSource.backup(); })["catch"](function (ex) {
                console.error('Post-sync backup failed', ex);
            });
            return syncPromise;
        }, 400, { leading: true });
    }, [dataSource]);
    var _c = __read(react_1["default"].useState(false), 2), initialized = _c[0], setInitialized = _c[1];
    react_1["default"].useEffect(function () {
        if (initialized) {
            return;
        }
        initialize(dataSource)["finally"](function () {
            if ((0, syncEngine_1.isSyncable)(dataSource)) {
                // Wrap the "index" method to trigger a re-render
                var originalIndex_1 = dataSource.index;
                dataSource.index = function (syncItem) {
                    originalIndex_1.call(dataSource, syncItem);
                    setRevision(function (i) { return (i + 1) % Number.MAX_SAFE_INTEGER; });
                };
            }
            setInitialized(true);
        });
    }, [dataSource]);
    if (!initialized) {
        if (Loading) {
            return react_1["default"].createElement(Loading);
        }
        return null;
    }
    return react_1["default"].createElement(context.Provider, {
        value: {
            dataSource: dataSource,
            revision: revision,
            resync: resync
        }
    }, children);
}
exports.LocalSchemaProvider = LocalSchemaProvider;
function useDataSource() {
    var ctx = react_1["default"].useContext(context);
    return [ctx.dataSource, ctx.revision, ctx.resync];
}
exports.useDataSource = useDataSource;
function initialize(dataSource) {
    return __awaiter(this, void 0, void 0, function () {
        var ex_1, ex_2;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (!(0, backup_1.hasBackup)(dataSource)) return [3 /*break*/, 4];
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 3, , 4]);
                    return [4 /*yield*/, dataSource.restore()];
                case 2:
                    _a.sent();
                    return [3 /*break*/, 4];
                case 3:
                    ex_1 = _a.sent();
                    console.error('Restore error, falling back to full sync:', ex_1);
                    return [3 /*break*/, 4];
                case 4:
                    if (!(0, syncEngine_1.hasSync)(dataSource)) return [3 /*break*/, 8];
                    _a.label = 5;
                case 5:
                    _a.trys.push([5, 7, , 8]);
                    return [4 /*yield*/, dataSource.sync()];
                case 6:
                    _a.sent();
                    return [3 /*break*/, 8];
                case 7:
                    ex_2 = _a.sent();
                    console.error('Sync error:', ex_2);
                    return [3 /*break*/, 8];
                case 8: return [2 /*return*/];
            }
        });
    });
}
//# sourceMappingURL=context.js.map