import type { Entry } from '../../contentful/types';
/**
 * The result is in one of 3 states:
 * 1. Loading, entry not available
 * 2. Error, entry may or may not be available
 * 3. Success, but entry may not have been found (undefined)
 *
 * Re-running the query does not set "loading: true", the loading flag is intended
 * for the initial load use case.
 */
export type UseFindEntryResult<T> = [
    Entry<T> | null | undefined,
    {
        error?: undefined;
        loading: boolean;
        refreshing: boolean;
    },
    () => Promise<void>
];
export declare function useFindEntry<T = any>(id: string, options?: {
    include?: number;
}): UseFindEntryResult<T>;
