export interface SchemaDownloaderOptions {
    /**
     * The name of the schema file.  Defaults to './contentful-schema.json'.
     */
    filename: string;
    /**
     * Contentful space ID.  Defaults to process.env.CONTENTFUL_SPACE_ID
     */
    space: string;
    /**
     * Contentful environment.
     *
     * Defaults to process.env.CONTENTFUL_ENVIRONMENT or 'master'
     */
    environment: string;
    /**
     * Contentful Management Access Token.
     *
     * Defaults to process.env.CONTENTFUL_MANAGEMENT_TOKEN
     */
    managementToken: string;
    logger: {
        debug: Console['debug'];
    };
}
export interface SchemaDownloaderDependencies {
    fetch: typeof globalThis.fetch;
}
/**
 * Downloads the Contentful schema via the management API and creates
 * the contentful-schema.json file.
 *
 *
 * @param options (Optional) Where to store the contentful content type file
 *   (default: './contentful-schema.json')
 * @returns
 */
export default function downloadContentfulSchema(options?: Partial<SchemaDownloaderOptions>, dependencies?: Partial<SchemaDownloaderDependencies>): Promise<void>;
export declare class SchemaDownloader {
    private readonly options;
    private readonly client;
    private readonly semaphore;
    private fetch;
    constructor(options?: Partial<SchemaDownloaderOptions>, dependencies?: Partial<SchemaDownloaderDependencies>);
    downloadSchema(): Promise<void>;
    private getSchemaFromSpace;
    private responseLogger;
}
