import { SyncItem } from '../contentful/types';
interface SyncCollection {
    entries: Array<{
        sys: any;
        fields: any;
    }>;
    assets: Array<{
        sys: any;
        fields: any;
    }>;
    deletedEntries: Array<{
        sys: any;
    }>;
    deletedAssets: Array<{
        sys: any;
    }>;
    nextSyncToken: string;
}
/**
 * This interface represents any Contentful client capable of using the Sync API.
 * A simple implementation of this interface is provided by this library, but you
 * can also use the official Contentful JS SDK.
 */
export interface ContentfulClientApi {
    sync(query: any): Promise<SyncCollection>;
}
export interface Syncable {
    getToken(): string | undefined | null | Promise<string | undefined | null>;
    setToken(token: string): void | Promise<void>;
    index(syncItem: SyncItem): void | Promise<void>;
}
export declare class SyncEngine {
    private readonly dataSource;
    private readonly client;
    constructor(dataSource: Syncable, client: ContentfulClientApi);
    sync(): Promise<void>;
}
/**
 * Enhances a dataSource with a Contentful client to keep it up to date via the
 * Sync API.
 * @param dataSource The data source to store data e.g. InMemoryDataSource, PostgresDataSource
 * @param client The Contentful client that allows us to sync data to the data source
 * @returns The same data source enhanced with the sync() method
 */
export declare function withSync<DataSource extends Syncable>(dataSource: DataSource, client: Pick<ContentfulClientApi, 'sync'>): DataSource & Pick<SyncEngine, 'sync'>;
/**
 * Enhances a dataSource with a Contentful client to keep it up to date via the
 * Sync API.
 * @param dataSource The data source to store data e.g. InMemoryDataSource, PostgresDataSource
 * @param client The Contentful client that allows us to sync data to the data source
 * @returns The same data source enhanced with the sync() method
 */
export declare function addSync<DataSource extends Syncable>(dataSource: DataSource, client: Pick<ContentfulClientApi, 'sync'>): asserts dataSource is DataSource & Pick<SyncEngine, 'sync'>;
export declare function isSyncable(dataSource: any): dataSource is Syncable;
export declare function hasSync(dataSource: any): dataSource is Pick<SyncEngine, 'sync'>;
export {};
