"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
exports.generateUUID = exports.unionTypeDefName = exports.isAssetLink = exports.isEntryLink = exports.isLink = exports.isDeletedAsset = exports.isDeletedEntry = exports.isAsset = exports.isEntry = exports.assertPresent = exports.present = exports.idToName = exports.isLinkContentTypeValidation = exports.tryParseJson = void 0;
var inflection_1 = __importDefault(require("inflection"));
function tryParseJson(json) {
    try {
        return JSON.parse(json);
    }
    catch (ex) {
        return null;
    }
}
exports.tryParseJson = tryParseJson;
function isLinkContentTypeValidation(v) {
    return 'linkContentType' in v && Array.isArray(v.linkContentType);
}
exports.isLinkContentTypeValidation = isLinkContentTypeValidation;
function idToName(id) {
    id = inflection_1["default"].underscore(id);
    id = id.replace(/[^\w]/g, ' ');
    id = inflection_1["default"].titleize(id);
    id = id.replace(/[\s+]/g, '');
    return id;
}
exports.idToName = idToName;
function present(value) {
    if (typeof value == 'string') {
        return /\S/.test(value);
    }
    return !!value;
}
exports.present = present;
function assertPresent(value) {
    if (!present(value)) {
        throw new Error("value '".concat(value, "' was not present"));
    }
}
exports.assertPresent = assertPresent;
function isEntry(e) {
    return e && e.sys && e.sys.type == 'Entry';
}
exports.isEntry = isEntry;
function isAsset(e) {
    return e && e.sys && e.sys.type == 'Asset';
}
exports.isAsset = isAsset;
function isDeletedEntry(e) {
    return e && e.sys && e.sys.type == 'DeletedEntry';
}
exports.isDeletedEntry = isDeletedEntry;
function isDeletedAsset(e) {
    return e && e.sys && e.sys.type == 'DeletedAsset';
}
exports.isDeletedAsset = isDeletedAsset;
function isLink(e) {
    return e && e.sys && e.sys.type == 'Link';
}
exports.isLink = isLink;
function isEntryLink(e) {
    return isLink(e) && e.sys.linkType == 'Entry';
}
exports.isEntryLink = isEntryLink;
function isAssetLink(e) {
    return isLink(e) && e.sys.linkType == 'Asset';
}
exports.isAssetLink = isAssetLink;
function unionTypeDefName(contentType, field) {
    return "".concat(idToName(contentType)).concat(inflection_1["default"].singularize(idToName(field.id)));
}
exports.unionTypeDefName = unionTypeDefName;
// https://stackoverflow.com/a/8809472/2192243
function generateUUID() {
    var d = new Date().getTime(); //Timestamp
    var d2 = ((typeof performance !== 'undefined') && performance.now && (performance.now() * 1000)) || 0; //Time in microseconds since page-load or 0 if unsupported
    return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
        var r = Math.random() * 16; //random number between 0 and 16
        if (d > 0) { //Use timestamp until depleted
            r = (d + r) % 16 | 0;
            d = Math.floor(d / 16);
        }
        else { //Use microseconds since page-load if supported
            r = (d2 + r) % 16 | 0;
            d2 = Math.floor(d2 / 16);
        }
        return (c === 'x' ? r : (r & 0x3 | 0x8)).toString(16);
    });
}
exports.generateUUID = generateUUID;
//# sourceMappingURL=util.js.map